/**
 * EasyBeans
 * Copyright (C) 2012 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TestNGActivator.java 6135 2012-01-24 17:02:48Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.testng4osgi;

import org.osgi.framework.Bundle;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.osgi.util.tracker.BundleTracker;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;
import org.ow2.util.maven.osgi.launcher.test.api.ITestLauncher;
import org.ow2.util.testng4osgi.launcher.TestNGLauncher;
import org.ow2.util.testng4osgi.tracker.TestNGBundleTracker;

/**
 * Bundle activator used to track all TestNG tests that are being added to the platform. 
 * @author Florent Benoit
 */
public class TestNGActivator implements BundleActivator {

    /**
     * Logger.
     */
    private static final Log LOGGER = LogFactory.getLog(TestNGActivator.class);

    /**
     * Tracking bundles (to detect testng tests).
     */
    private BundleTracker bundleTracker = null;

    /**
     * Our registration when we're ready
     */
    private ServiceRegistration<ITestLauncher> registration = null;

    /**
     * Start the activator.
     */
    public void start(BundleContext bundleContext) throws Exception {

        // New launcher
        TestNGLauncher testNGLauncher = new TestNGLauncher();

        // start tracking bundles
        bundleTracker = new BundleTracker(bundleContext, Bundle.ACTIVE, new TestNGBundleTracker(testNGLauncher));
        bundleTracker.open();

        // Registering the service as we're ready
        LOGGER.debug("Registering service ''{0}''", ITestLauncher.class);
        registration = bundleContext.registerService(ITestLauncher.class, testNGLauncher, null);

    }

    /**
     * Stop the activator.
     */
    public void stop(BundleContext context) throws Exception {
        // unregister
        if (registration != null) {
            registration.unregister();
        }

        // stop tracking
        if (bundleTracker != null) {
            bundleTracker.close();
        }

    }

}
